==> openteacher_3.0.orig.tar.gz: openteacher-3.0/openteacher/modules/org/openteacher/wordsString/javaScriptComposer/javaScriptComposer.py <==
#! /usr/bin/env python
# -*- coding: utf-8 -*-

#	Copyright 2012, Marten de Vries
#
#	This file is part of OpenTeacher.
#
#	OpenTeacher is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	OpenTeacher is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with OpenTeacher.  If not, see <http://www.gnu.org/licenses/>.

from PyQt4 import QtScript
try:
	import json
except ImportError:
	import simplejson as json

class JavascriptComposerModule(object):
	def __init__(self, moduleManager, *args, **kwargs):
		super(JavascriptComposerModule, self).__init__(*args, **kwargs)
		self._mm = moduleManager

		self.type = "wordsStringComposer"
		self.javaScriptImplementation = True
		self.requires = (
			self._mm.mods(type="ui"),
		)
		self.priorities = {
			"default": 20,
		}

	def _checkForErrors(self):
		if self._engine.hasUncaughtException():
			raise Exception(self._engine.uncaughtException().toString())

	def compose(self, word):
		v = self._engine.evaluate("compose(%s)" % json.dumps(word))
		self._checkForErrors()

		return unicode(v.toString())

	def enable(self):
		self._engine = QtScript.QScriptEngine()
		with open(self._mm.resourcePath("composer.js")) as f:
			self.code = f.read()
		self._engine.evaluate(self.code, f.name)
		self._checkForErrors()

		self.active = True

	def disable(self):
		self.active = False

		del self._engine
		del self.code

def init(moduleManager):
	return JavascriptComposerModule(moduleManager)

==> openteacher_3.1.orig.tar.gz: openteacher-3.1/openteacher/modules/org/openteacher/wordsString/javaScriptComposer/javaScriptComposer.py <==
#! /usr/bin/env python
# -*- coding: utf-8 -*-

#	Copyright 2013, Marten de Vries
#
#	This file is part of OpenTeacher.
#
#	OpenTeacher is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	OpenTeacher is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with OpenTeacher.  If not, see <http://www.gnu.org/licenses/>.

class JavascriptComposerModule(object):
	def __init__(self, moduleManager, *args, **kwargs):
		super(JavascriptComposerModule, self).__init__(*args, **kwargs)
		self._mm = moduleManager

		self.type = "wordsStringComposer"
		self.javaScriptImplementation = True
		self.requires = (
			self._mm.mods(type="javaScriptEvaluator"),
		)
		self.priorities = {
			"default": 20,
		}

	def compose(self, *args, **kwargs):
		return self._js["compose"](*args, **kwargs)

	def enable(self):
		with open(self._mm.resourcePath("composer.js")) as f:
			self.code = f.read()

		modules = next(iter(self._mm.mods(type="modules")))
		self._js = modules.default("active", type="javaScriptEvaluator").createEvaluator()
		self._js.eval(self.code)

		self.active = True

	def disable(self):
		self.active = False

		del self._js
		del self.code

def init(moduleManager):
	return JavascriptComposerModule(moduleManager)
